About
------
This biblioteque creates the io games on Python.
It isn't better, than pygame, but it soon update

Installing
------
Enter in your bash:
    pip install io_games


Using
------
It has got one modules: display

And about this module, enter in your bash:
    python -m io_games.docs

Goodbye!